dystopia
=====

Use permitted according to the terms of use and conditions set by the attached license.

**A word from the author!**

The library itself, it's maintenance, updates and stability, logo, videos, promotional materials and everything associated with dystopia are done by **David Kundih** from **Croatia**.

<h1 align='center'> Hi! :wave:</h1>
 
<img src='https://raw.githubusercontent.com/dkundih/dkundih/main/.logistics/BLUERED_GHiLI.jpg'/>

<p align='center'>
My name is <b>David Kundih</b> and I am a <b>Master of Engineering in Sustainable Mobility and Logistics</b>, currently specializing in <b>Digital Transformation of Traffic and Logistics using Python.</b>
</p>
 
<h4 align='center'>My latest projects:</h4>
<p align='center'>
<a href="https://github.com/dkundih/vandal">vandal</p>  
<p align='center'>
<a href="https://github.com/dkundih/duality">duality</p>
<p align='center'>
<a href="https://github.com/dkundih/logistics">logistics</p>    
<p align='center'>
<a href="https://github.com/dkundih/unin">unin</a></p>
</p>

<h3 align='center'><i>People shine the brightest when they seek to understand what kind of love sustains them.</i></h3>

<p align='center'>
<a href="https://www.instagram.com/dkundih/"><img height="25" src="https://raw.githubusercontent.com/dkundih/dkundih/main/.logistics/instagram.jpg"></a>
<a href="https://www.facebook.com/dkundih/"><img height="25" src="https://raw.githubusercontent.com/dkundih/dkundih/main/.logistics/fb.jpg"></a>
<a href="https://www.linkedin.com/in/dkundih/"><img height="25" src="https://raw.githubusercontent.com/dkundih/dkundih/main/.logistics/linkedin.png"></a>
<a href="https://www.pypi.org/user/dkundih/"><img height="25" src="https://raw.githubusercontent.com/dkundih/dkundih/main/.logistics/pypi.jpg"></a>
<a href="https://www.buymeacoffee.com/dkundih"><img height="25" src="https://raw.githubusercontent.com/dkundih/dkundih/main/.logistics/buymeacoffee.jpg"></a>
<a href="https://www.patreon.com/dkundih"><img height="25" src="https://raw.githubusercontent.com/dkundih/dkundih/main/.logistics/patreon.jpg"></a>
<a href="https://www.behance.net/dkundih"><img height="25" src="https://raw.githubusercontent.com/dkundih/dkundih/main/.logistics/behance.jpg"></a>
<a href="https://www.researchgate.net/profile/David-Kundih"><img height="25" src="https://raw.githubusercontent.com/dkundih/dkundih/main/.logistics/rg.jpg"></a>
